@@ -42,7 +42,7 @@ class TestProtected:
         """Test for unprotected mainline branch."""
         query_data["default_branch_data"] = {"protected": True}
         # Don't protect mainline branch
-        requirement_args = {"disabled": True}
+        requirement_args = {"no": True}
         result = requirement.Evaluate(query_data, requirement_args)
         assert result.result == EvaluateResult.Error
         assert result.rationale is None
@@ -50,7 +50,7 @@ class TestProtected:
 
     def test_ProtectedMainlineBranch(self, requirement, query_data):
         """Test for protected mainline branch"""
-        requirement_args = {"disabled": False}
+        requirement_args = {"no": False}
         result = requirement.Evaluate(query_data, requirement_args)
         assert result.result == EvaluateResult.Success
         assert result.rationale is None
@@ -59,7 +59,7 @@ class TestProtected:
     def test_is_protected_False(self, requirement, query_data):
         """Test when is_protected is False"""
         query_data["default_branch_data"]["protected"] = False
-        requirement_args = {"disabled": False}
+        requirement_args = {"no": False}
         result = requirement.Evaluate(query_data, requirement_args)
         assert result.result == EvaluateResult.Error
         assert result.rationale is not None
