@@ -30,6 +30,11 @@ def requirement_fixture():
     return SquashMergeCommitMessage()
 
 
+@pytest.fixture(name="requirement_args")
+def requirement_args_fixture():
+    return {"value": "COMMIT_MESSAGES"}
+
+
 class TestSquashMergeCommitMessage:
     """Tests for the SquashMergeCommitMessage requirement class."""
 
@@ -41,34 +46,30 @@ class TestSquashMergeCommitMessage:
         assert result.result == EvaluateResult.Warning
         assert "Incomplete data was encountered" in result.context
 
-    def test_Disabled(self, requirement, query_data):
+    def test_Disabled(self, requirement, query_data, requirement_args):
         """Test when squash merges are disabled"""
         query_data["standard"]["allow_squash_merge"] = False
-        requirement_args = {"value": "COMMIT_MESSAGES"}
         result = requirement.Evaluate(query_data, requirement_args)
         assert result.result == EvaluateResult.DoesNotApply
         assert "Squash merge commits are not enabled." in result.context
 
-    def test_MissingValue(self, requirement, query_data):
+    def test_MissingValue(self, requirement, query_data, requirement_args):
         """Missing squash_merge_commit_message value"""
         query_data["standard"]["allow_squash_merge"] = True
         query_data["standard"].pop("squash_merge_commit_message", None)
-        requirement_args = {"value": "COMMIT_MESSAGES"}
         result = requirement.Evaluate(query_data, requirement_args)
         assert result.result == EvaluateResult.Warning
         assert "Incomplete data was encountered" in result.context
 
-    def test_CommitMessage(self, requirement, query_data):
+    def test_CommitMessage(self, requirement, query_data, requirement_args):
         """With COMMIT_MESSAGES squash-merge commit message value"""
         query_data["standard"]["squash_merge_commit_message"] = "COMMIT_MESSAGES"
-        requirement_args = {"value": "COMMIT_MESSAGES"}
         result = requirement.Evaluate(query_data, requirement_args)
         assert result.result == EvaluateResult.Success
 
-    def test_IncorrectValue(self, requirement, query_data):
+    def test_IncorrectValue(self, requirement, query_data, requirement_args):
         """With incorrect commit message value"""
         query_data["standard"]["squash_merge_commit_message"] = "NO_COMMIT_MESSAGES"
-        requirement_args = {"value": "COMMIT_MESSAGES"}
         result = requirement.Evaluate(query_data, requirement_args)
         assert result.result == EvaluateResult.Error
         assert "it is currently set to 'NO_COMMIT_MESSAGES'" in result.context
