@@ -72,105 +72,105 @@ def test_NoPAT(snapshot, args):
 class TestStandard:
     # ----------------------------------------------------------------------
     def test_NoAutoMerge(self, pat_args, snapshot):
-        result = CliRunner().invoke(app, pat_args + ["--GitHub-AutoMerge-disabled"])
+        result = CliRunner().invoke(app, pat_args + ["--GitHub-no-AutoMerge"])
 
         assert result.exit_code == -1, result.output
         assert ScrubDurationGithuburlAndSpaces(result.stdout) == snapshot
 
     # ----------------------------------------------------------------------
     def test_NoDeleteHeadBranches(self, pat_args, snapshot):
-        result = CliRunner().invoke(app, pat_args + ["--GitHub-DeleteHeadBranches-disabled"])
+        result = CliRunner().invoke(app, pat_args + ["--GitHub-no-DeleteHeadBranches"])
 
         assert result.exit_code == -1, result.output
         assert ScrubDurationGithuburlAndSpaces(result.stdout) == snapshot
 
     # ----------------------------------------------------------------------
     def test_NoDependabotSecurityUpdates(self, pat_args, snapshot):
-        result = CliRunner().invoke(app, pat_args + ["--GitHub-DependabotSecurityUpdates-disabled"])
+        result = CliRunner().invoke(app, pat_args + ["--GitHub-no-DependabotSecurityUpdates"])
 
         assert result.exit_code == -1, result.output
         assert ScrubDurationGithuburlAndSpaces(result.stdout) == snapshot
 
     # ----------------------------------------------------------------------
     def test_NoMergeCommit(self, pat_args, snapshot):
-        result = CliRunner().invoke(app, pat_args + ["--GitHub-MergeCommit-disabled"])
+        result = CliRunner().invoke(app, pat_args + ["--GitHub-no-MergeCommit"])
 
         assert result.exit_code == -1, result.output
         assert ScrubDurationGithuburlAndSpaces(result.stdout) == snapshot
 
     # ----------------------------------------------------------------------
     def test_YesRebaseMergeCommit(self, pat_args, snapshot):
-        result = CliRunner().invoke(app, pat_args + ["--GitHub-RebaseMergeCommit-enabled"])
+        result = CliRunner().invoke(app, pat_args + ["--GitHub-RebaseMergeCommit"])
 
         assert result.exit_code == -1, result.output
         assert ScrubDurationGithuburlAndSpaces(result.stdout) == snapshot
 
     # ----------------------------------------------------------------------
     def test_NoSecretScanning(self, pat_args, snapshot):
-        result = CliRunner().invoke(app, pat_args + ["--GitHub-SecretScanning-disabled"])
+        result = CliRunner().invoke(app, pat_args + ["--GitHub-no-SecretScanning"])
 
         assert result.exit_code == -1, result.output
         assert ScrubDurationGithuburlAndSpaces(result.stdout) == snapshot
 
     # ----------------------------------------------------------------------
     def test_NoSecretScanningPushProtection(self, pat_args, snapshot):
-        result = CliRunner().invoke(app, pat_args + ["--GitHub-SecretScanningPushProtection-disabled"])
+        result = CliRunner().invoke(app, pat_args + ["--GitHub-no-SecretScanningPushProtection"])
 
         assert result.exit_code == -1, result.output
         assert ScrubDurationGithuburlAndSpaces(result.stdout) == snapshot
 
     # ----------------------------------------------------------------------
     def test_YesSquashCommitMerge(self, pat_args, snapshot):
-        result = CliRunner().invoke(app, pat_args + ["--GitHub-SquashCommitMerge-enabled"])
+        result = CliRunner().invoke(app, pat_args + ["--GitHub-SquashCommitMerge"])
 
         assert result.exit_code == -1, result.output
         assert ScrubDurationGithuburlAndSpaces(result.stdout) == snapshot
 
     # ----------------------------------------------------------------------
     def test_YesSuggestUpdatingPullRequestBranches(self, pat_args, snapshot):
-        result = CliRunner().invoke(app, pat_args + ["--GitHub-SuggestUpdatingPullRequestBranches-enabled"])
+        result = CliRunner().invoke(app, pat_args + ["--GitHub-SuggestUpdatingPullRequestBranches"])
 
         assert result.exit_code == -1, result.output
         assert ScrubDurationGithuburlAndSpaces(result.stdout) == snapshot
 
     # ----------------------------------------------------------------------
     def test_YesSupportDiscussions(self, pat_args, snapshot):
-        result = CliRunner().invoke(app, pat_args + ["--GitHub-SupportDiscussions-enabled"])
+        result = CliRunner().invoke(app, pat_args + ["--GitHub-SupportDiscussions"])
 
         assert result.exit_code == -1, result.output
         assert ScrubDurationGithuburlAndSpaces(result.stdout) == snapshot
 
     # ----------------------------------------------------------------------
     def test_NoSupportIssues(self, pat_args, snapshot):
-        result = CliRunner().invoke(app, pat_args + ["--GitHub-SupportIssues-disabled"])
+        result = CliRunner().invoke(app, pat_args + ["--GitHub-no-SupportIssues"])
 
         assert result.exit_code == -1, result.output
         assert ScrubDurationGithuburlAndSpaces(result.stdout) == snapshot
 
     # ----------------------------------------------------------------------
     def test_NoSupportProjects(self, pat_args, snapshot):
-        result = CliRunner().invoke(app, pat_args + ["--GitHub-SupportProjects-disabled"])
+        result = CliRunner().invoke(app, pat_args + ["--GitHub-no-SupportProjects"])
 
         assert result.exit_code == -1, result.output
         assert ScrubDurationGithuburlAndSpaces(result.stdout) == snapshot
 
     # ----------------------------------------------------------------------
     def test_NoSupportWikis(self, pat_args, snapshot):
-        result = CliRunner().invoke(app, pat_args + ["--GitHub-SupportWikis-disabled"])
+        result = CliRunner().invoke(app, pat_args + ["--GitHub-no-SupportWikis"])
 
         assert result.exit_code == -1, result.output
         assert ScrubDurationGithuburlAndSpaces(result.stdout) == snapshot
 
     # ----------------------------------------------------------------------
     def test_YesTemplateRepository(self, pat_args, snapshot):
-        result = CliRunner().invoke(app, pat_args + ["--GitHub-TemplateRepository-enabled"])
+        result = CliRunner().invoke(app, pat_args + ["--GitHub-TemplateRepository"])
 
         assert result.exit_code == -1, result.output
         assert ScrubDurationGithuburlAndSpaces(result.stdout) == snapshot
 
     # ----------------------------------------------------------------------
     def test_NoWebCommitSignoff(self, pat_args, snapshot):
-        result = CliRunner().invoke(app, pat_args + ["--GitHub-WebCommitSignoff-disabled"])
+        result = CliRunner().invoke(app, pat_args + ["--GitHub-no-WebCommitSignoff"])
 
         assert result.exit_code == -1, result.output
         assert ScrubDurationGithuburlAndSpaces(result.stdout) == snapshot
@@ -235,7 +235,7 @@ class TestStandard:
     def test_PrivateValue(self, pat_args, snapshot):
         result = CliRunner().invoke(
             app,
-            pat_args + ["--GitHub-Private-enabled"],
+            pat_args + ["--GitHub-Private"],
         )
 
         assert result.exit_code == -1, result.output
@@ -259,7 +259,7 @@ class TestStandard:
     def test_Protected(self, pat_args, snapshot):
         result = CliRunner().invoke(
             app,
-            pat_args + ["--GitHub-Protected-disabled"],
+            pat_args + ["--GitHub-no-Protected"],
         )
 
         assert result.exit_code == -1, result.output
@@ -272,7 +272,7 @@ class TestClassic:
     def test_AllowDeletions(self, pat_args, snapshot):
         result = CliRunner().invoke(
             app,
-            pat_args + ["--GitHub-AllowDeletions-enabled"],
+            pat_args + ["--GitHub-AllowDeletions"],
         )
 
         assert result.exit_code == -1, result.output
@@ -282,7 +282,7 @@ class TestClassic:
     def test_AllowMainlineForcePush(self, pat_args, snapshot):
         result = CliRunner().invoke(
             app,
-            pat_args + ["--GitHub-AllowMainlineForcePushes-enabled"],
+            pat_args + ["--GitHub-AllowMainlineForcePushes"],
         )
 
         assert result.exit_code == -1, result.output
@@ -292,7 +292,7 @@ class TestClassic:
     def test_DismissStalePullRequestApprovals(self, pat_args, snapshot):
         result = CliRunner().invoke(
             app,
-            pat_args + ["--GitHub-DismissStalePullRequestApprovals-disabled"],
+            pat_args + ["--GitHub-no-DismissStalePullRequestApprovals"],
         )
 
         assert result.exit_code == -1, result.output
@@ -302,7 +302,7 @@ class TestClassic:
     def test_DoNotAllowBypassSettings(self, pat_args, snapshot):
         result = CliRunner().invoke(
             app,
-            pat_args + ["--GitHub-DoNotAllowBypassSettings-disabled"],
+            pat_args + ["--GitHub-no-DoNotAllowBypassSettings"],
         )
 
         assert result.exit_code == -1, result.output
@@ -312,7 +312,7 @@ class TestClassic:
     def test_EnsureStatusChecks(self, pat_args):
         result = CliRunner().invoke(
             app,
-            pat_args + ["--GitHub-EnsureStatusChecks-disabled", "--verbose"],
+            pat_args + ["--GitHub-no-EnsureStatusChecks", "--verbose"],
         )
 
         assert result.exit_code == 0, result.output
@@ -322,7 +322,7 @@ class TestClassic:
     def test_RequireApprovalMostRecentPush(self, pat_args, snapshot):
         result = CliRunner().invoke(
             app,
-            pat_args + ["--GitHub-RequireApprovalMostRecentPush-disabled"],
+            pat_args + ["--GitHub-no-RequireApprovalMostRecentPush"],
         )
 
         assert result.exit_code == -1, result.output
@@ -342,7 +342,7 @@ class TestClassic:
     def test_RequireCodeOwnerReview(self, pat_args, snapshot):
         result = CliRunner().invoke(
             app,
-            pat_args + ["--GitHub-RequireCodeOwnerReview-enabled"],
+            pat_args + ["--GitHub-RequireCodeOwnerReview"],
         )
 
         assert result.exit_code == -1, result.output
@@ -352,7 +352,7 @@ class TestClassic:
     def test_RequireConversationResolution(self, pat_args, snapshot):
         result = CliRunner().invoke(
             app,
-            pat_args + ["--GitHub-RequireConversationResolution-disabled"],
+            pat_args + ["--GitHub-no-RequireConversationResolution"],
         )
 
         assert result.exit_code == -1, result.output
@@ -362,7 +362,7 @@ class TestClassic:
     def test_RequireLinearHistory(self, pat_args, snapshot):
         result = CliRunner().invoke(
             app,
-            pat_args + ["--GitHub-RequireLinearHistory-enabled"],
+            pat_args + ["--GitHub-RequireLinearHistory"],
         )
 
         assert result.exit_code == -1, result.output
@@ -372,7 +372,7 @@ class TestClassic:
     def test_RequirePullRequests(self, pat_args, snapshot):
         result = CliRunner().invoke(
             app,
-            pat_args + ["--GitHub-RequirePullRequests-disabled"],
+            pat_args + ["--GitHub-no-RequirePullRequests"],
         )
 
         assert result.exit_code == -1, result.output
@@ -382,7 +382,7 @@ class TestClassic:
     def test_RequireSignedCommits(self, pat_args, snapshot):
         result = CliRunner().invoke(
             app,
-            pat_args + ["--GitHub-RequireSignedCommits-disabled"],
+            pat_args + ["--GitHub-no-RequireSignedCommits"],
         )
 
         assert result.exit_code == -1, result.output
@@ -392,7 +392,7 @@ class TestClassic:
     def test_RequireStatusChecksToPass(self, pat_args, snapshot):
         result = CliRunner().invoke(
             app,
-            pat_args + ["--GitHub-RequireStatusChecksToPass-disabled"],
+            pat_args + ["--GitHub-no-RequireStatusChecksToPass"],
         )
 
         assert result.exit_code == -1, result.output
@@ -402,7 +402,7 @@ class TestClassic:
     def test_RequireUpToDateBranches(self, pat_args, snapshot):
         result = CliRunner().invoke(
             app,
-            pat_args + ["--GitHub-RequireUpToDateBranches-disabled"],
+            pat_args + ["--GitHub-no-RequireUpToDateBranches"],
         )
 
         assert result.exit_code == -1, result.output
@@ -438,7 +438,7 @@ class TestRulesets:
 
     def test_RequireStatusChecks(self, pat_args, snapshot):
         """Test for requirement `Require status checks to pass` is disabled in the ruleset for the `main` branch."""
-        result = CliRunner().invoke(app, pat_args + ["--GitHub-RequireStatusChecksRule-disabled"])
+        result = CliRunner().invoke(app, pat_args + ["--GitHub-no-RequireStatusChecksRule"])
 
         # Since the repo ruleset has the requirement enabled,
         # we should get an error.
@@ -447,7 +447,7 @@ class TestRulesets:
 
     def test_RequirePullRequests(self, pat_args, snapshot):
         """Test for requirement `Require a pull request before merging` is disabled in the ruleset for the `main` branch."""
-        result = CliRunner().invoke(app, pat_args + ["--GitHub-RequirePullRequestsRule-disabled"])
+        result = CliRunner().invoke(app, pat_args + ["--GitHub-no-RequirePullRequestsRule"])
 
         # Since the repo ruleset has the requirement disabled,
         # we should get an error.
@@ -456,7 +456,7 @@ class TestRulesets:
 
     def test_RequireSignedCommits(self, pat_args, snapshot):
         """Test for requirement `Require signed commits` is disabled in the ruleset for the `main` branch."""
-        result = CliRunner().invoke(app, pat_args + ["--GitHub-RequireSignedCommitsRule-disabled"])
+        result = CliRunner().invoke(app, pat_args + ["--GitHub-no-RequireSignedCommitsRule"])
 
         # Since the repo ruleset has the requirement disabled,
         # we should get an error.
